@@ -13,8 +13,11 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
+# Fonts
+ADDRESS_MONOSPACE_FONT_NAME = "Courier"
+
 # icon paths
-ICON_ACCOUNT_NO_WALLET = ":/icons/lock_closed"
+ICON_ACCOUNT_NO_WALLET = ":/images/locked_no_wallet"
 ICON_ACCOUNT_WALLET_LOCKED = ":/images/locked"
 ICON_ACCOUNT_WALLET_UNLOCKED = ":/images/unlocked"
 ICON_NETWORK_CONNECTED = ":/icons/connected"
