@@ -15,7 +15,7 @@
 from __future__ import annotations
 
 import pickle
-from typing import TYPE_CHECKING, Any, Iterable, List, Optional, Tuple, Type, Union
+from typing import Any, Iterable, List, Optional, Tuple, Type, Union
 from uuid import UUID
 
 from PyQt5.QtCore import QAbstractItemModel, QMimeData, QModelIndex, Qt, QVariant
@@ -23,19 +23,16 @@ from PyQt5.QtGui import QFont, QIcon, QPixmap
 
 from tikka.domains.application import Application
 from tikka.domains.entities.account import Account
-from tikka.domains.entities.address import DisplayAddress
 from tikka.domains.entities.category import Category
 from tikka.domains.entities.identity import STATUS_VALIDATED
 from tikka.slots.pyqt.entities.constants import (
+    ADDRESS_MONOSPACE_FONT_NAME,
     ICON_ACCOUNT_NO_WALLET,
     ICON_ACCOUNT_WALLET_LOCKED,
     ICON_ACCOUNT_WALLET_UNLOCKED,
     ICON_IDENTITY,
 )
 
-if TYPE_CHECKING:
-    import _
-
 MemberStatusRole = Qt.UserRole + 1000
 
 
@@ -145,7 +142,7 @@ class AccountTreeModel(QAbstractItemModel):
         self.mime_type = "application/vnd.text.list"
 
         # Number of column displayed, see self.data()
-        self._column_count = 1
+        self._column_count = 2
 
         self.root_item = TreeItem(None, None)
 
@@ -270,36 +267,31 @@ class AccountTreeModel(QAbstractItemModel):
             return data
 
         tree_item = index.internalPointer()
-        # display account adress or category name in first column
+        # display account address or category name in first column
         # only this column is indented
         if index.column() == 0 and role in (Qt.DisplayRole, Qt.EditRole):
-            if isinstance(tree_item.element, Account):
-                data_columns = []
-                if tree_item.element.name is not None:
-                    data_columns.append(
-                        DisplayAddress(tree_item.element.address).shorten
-                    )
-                    data_columns.append(tree_item.element.name)
-                else:
-                    data_columns.append(
-                        DisplayAddress(tree_item.element.address).shorten
-                        if tree_item.element.root is None
-                        else tree_item.element.address
-                    )
-                data = QVariant(" ".join(data_columns))
-            else:
-                data = QVariant(tree_item.element.name)
+            data = QVariant(tree_item.element.name)
 
-        # display root account in italic
         if (
-            index.column() == 0
-            and role == Qt.FontRole
+            index.column() == 1
+            and role == Qt.DisplayRole
             and isinstance(tree_item.element, Account)
         ):
-            if tree_item.element.root is None:
+            data = QVariant(tree_item.element.address)
+
+        if role == Qt.FontRole and isinstance(tree_item.element, Account):
+            if index.column() == 1:
+                # display addresses in monospace font
+                font = QFont(ADDRESS_MONOSPACE_FONT_NAME)
+                # if font is not found, choose equivalent monospace font on system
+                font.setStyleHint(QFont.Monospace)
+                # font.setBold(True)
+            else:
                 font = QFont()
-                font.setItalic(True)
-                return QVariant(font)
+            # display root account with underline
+            if tree_item.element.root is None:
+                font.setUnderline(True)
+            return QVariant(font)
 
         # display wallet lock status icon for account in first column
         if (
@@ -390,7 +382,7 @@ class AccountTreeModel(QAbstractItemModel):
         """
         Insert row in parent index
 
-        :param row: Row position in parent children
+        :param row: Index of row from 0 in parent children
         :param parent: QModelIndex instance
         :return:
         """
