@@ -16,16 +16,17 @@ import sys
 from typing import Optional
 
 from PyQt5.QtCore import QMutex, QPoint
-from PyQt5.QtGui import QPixmap
+from PyQt5.QtGui import QFont, QPixmap
 from PyQt5.QtWidgets import QApplication, QMainWindow, QWidget
 
 from tikka.domains.application import Application
 from tikka.domains.entities.account import Account
 from tikka.domains.entities.address import DisplayAddress
-from tikka.domains.entities.constants import DATA_PATH
+from tikka.domains.entities.constants import AMOUNT_UNIT_KEY, DATA_PATH
 from tikka.domains.entities.events import AccountEvent, TransferEvent, UnitEvent
 from tikka.interfaces.adapters.repository.preferences import SELECTED_UNIT
 from tikka.slots.pyqt.entities.constants import (
+    ADDRESS_MONOSPACE_FONT_NAME,
     ICON_ACCOUNT_NO_WALLET,
     ICON_ACCOUNT_WALLET_LOCKED,
     ICON_ACCOUNT_WALLET_UNLOCKED,
@@ -66,7 +67,10 @@ class AccountWidget(QWidget, Ui_AccountWidget):
         self.account = account
         self.mutex = mutex
 
-        self.addressLabel.setText(self.account.address)
+        self.monospace_font = QFont(ADDRESS_MONOSPACE_FONT_NAME)
+        self.monospace_font.setStyleHint(QFont.Monospace)
+        self.addressValueLabel.setFont(self.monospace_font)
+        self.addressValueLabel.setText(self.account.address)
 
         self._update_ui()
 
@@ -159,9 +163,13 @@ class AccountWidget(QWidget, Ui_AccountWidget):
             "ConfirmedByOwner": self._("Confirmed"),
             "Unknown": self._("Unknown"),
         }
-        amount = self.application.amounts.get_amount(
-            self.application.preferences_repository.get(SELECTED_UNIT)
-        )
+
+        unit_preference = self.application.preferences_repository.get(SELECTED_UNIT)
+        if unit_preference is not None:
+            amount = self.application.amounts.get_amount(unit_preference)
+        else:
+            amount = self.application.amounts.get_amount(AMOUNT_UNIT_KEY)
+
         if self.account.name is None:
             self.nameLabel.setText("")
         else:
@@ -200,8 +208,10 @@ class AccountWidget(QWidget, Ui_AccountWidget):
         else:
             root_account = self.application.accounts.get_by_address(self.account.root)
             if root_account is not None and root_account.name is not None:
+                self.derivationValueLabel.setFont(QFont())
                 self.derivationValueLabel.setText(root_account.name + self.account.path)
             else:
+                self.derivationValueLabel.setFont(self.monospace_font)
                 self.derivationValueLabel.setText(
                     DisplayAddress(self.account.root).shorten + self.account.path
                 )
