@@ -24,7 +24,7 @@ from substrateinterface.utils.ss58 import is_valid_ss58_address
 
 from tikka.domains.application import Application
 from tikka.domains.entities.account import Account
-from tikka.domains.entities.constants import DATA_PATH
+from tikka.domains.entities.constants import AMOUNT_UNIT_KEY, DATA_PATH
 from tikka.interfaces.adapters.repository.preferences import SELECTED_UNIT
 from tikka.slots.pyqt.entities.constants import ICON_LOADER
 from tikka.slots.pyqt.entities.worker import AsyncQWorker
@@ -67,7 +67,13 @@ class TransferWindow(QDialog, Ui_TransferDialog):
         self._("Transfer/payment would kill account")
         self._("Balance too low to send value")
 
-        self.unit = self.application.preferences_repository.get(SELECTED_UNIT)
+        # init unit from preference or default
+        unit_preference = self.application.preferences_repository.get(SELECTED_UNIT)
+        if unit_preference is not None:
+            self.unit = unit_preference
+        else:
+            self.unit = AMOUNT_UNIT_KEY
+
         self.init_units()
 
         self.recipient_account: Optional[Account] = None
@@ -344,8 +350,8 @@ class TransferWindow(QDialog, Ui_TransferDialog):
 
         :return:
         """
-        # get value as blockchain units
         amount = self.application.amounts.get_amount(self.unit)
+        # get value as blockchain units
         blockchain_value = amount.blockchain_value(self.amountDoubleSpinBox.value())
         self.fees = self.application.transfers.fees(
             self.account, self.recipient_account.address, blockchain_value
